Learn R Programming

madness (version 0.2.4)

as.madness: Coerce to a madness object.

Description

Convert model to a madness object.

Usage

as.madness(x, vtag=NULL, xtag=NULL)

# S3 method for default as.madness(x, vtag = NULL, xtag = NULL)

Arguments

x

an object which can be fed to coef, and possibly vcov

vtag

an optional name for the \(val\) variable.

xtag

an optional name for the \(X\) variable.

Value

A madness object.

Details

Attempts to stuff the coefficients and variance-covariance matrix of a model into a madness object.

Examples

Run this code
# NOT RUN {
xy <- data.frame(x=rnorm(100),y=runif(100),z=runif(100))
amod <- lm(z ~ x + y,xy)
amad <- as.madness(amod)
# }

Run the code above in your browser using DataLab