Learn R Programming

madness (version 0.2.4)

colsums: Form Row and Column Sums and Means

Description

Form Row and Column Sums and Means for madness objects.

Usage

# S4 method for madness
colSums(x, na.rm = FALSE, dims = 1)

# S4 method for madness colMeans(x, na.rm = FALSE, dims = 1)

# S4 method for madness rowSums(x, na.rm = FALSE, dims = 1)

# S4 method for madness rowMeans(x, na.rm = FALSE, dims = 1)

Arguments

x

madness object.

na.rm

logical. Should missing values (including NaN) be omitted from the calculations?

dims

integer: Which dimensions are regarded as ‘rows’ or ‘columns’ to sum over. For row*, the sum or mean is over dimensions dims+1, …; for col* it is over dimensions 1:dims.

...

potentially further arguments, for method ‘<->’ generic compatibility.

Value

a madness object. Note that the sums are flattened to a column vector.