det: Matrix Determinant

detR Documentation

Matrix Determinant

Description

Compute the determinant of a matrix. As for base::determinant, a list of the modulus and sign are returned.

Usage

## S3 method for class 'madness'
determinant(x, logarithm = TRUE, ...)

det(x, ...)

## S4 method for signature 'madness,ANY'
determinant(x, logarithm = TRUE, ...)

## S4 method for signature 'madness,missing'
determinant(x, logarithm = TRUE, ...)

## S4 method for signature 'madness,logical'
determinant(x, logarithm = TRUE, ...)

Arguments

x

madness object.

logarithm

logical; if TRUE (default) return the logarithm of the modulus of the determinant.

...

optional arguments, currently unused.

Value

a list with elements modulus and sign, which are madness objects.

Note

throws an error for non-square matrices or non-matrix input.

Author(s)

Steven E. Pav shabbychef@gmail.com


madness documentation built on July 15, 2026, 1:08 a.m.