extract-methods: Extract parts of a 'madness' value.

[R Documentation

Extract parts of a madness value.

Description

Extract parts of a madness value.

Usage

## S4 method for signature 'madness,ANY,ANY,ANY'
x[i, j, ..., drop = TRUE]

## S4 method for signature 'madness,ANY,missing,ANY'
x[i, j, ..., drop = TRUE]

Arguments

x

a madness object.

i

indices specifying elements to extract or replace.

j, ...

furtheh indices specifying elements to extract or replace.

drop

relevant for matrices and arrays. If TRUE the result is coerced to the lowest possible dimension (see the examples). This only works for extracting elements, not for the replacement. See drop for further details.

Author(s)

Steven E. Pav shabbychef@gmail.com


madness documentation built on July 15, 2026, 1:08 a.m.