madness-pkg: Multivariate Automatic Differentiation.
Description
Automatic Differentiation of Matrix Operations.Legal Mumbo Jumbo
madness is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
GNU Lesser General Public License for more details.References
Griewank, Andreas and Walther, Andrea. "Evaluating Derivatives: principles and techniques of algorithmic differentiation."
SIAM (2008). Petersen, Kaare Brandt and Pedersen, Michael Syskind. "The Matrix Cookbook."
Technical University of Denmark (2012).
http://www2.imm.dtu.dk/pubdb/p.php?3274 Magnus, Jan R. and Neudecker, H. "Matrix Differential Calculus with Applications in Statistics and Econometrics."
3rd Edition. Wiley Series in Probability and Statistics: Texts and References Section (2007).
http://www.janmagnus.nl/misc/mdc2007-3rdedition Magnus, Jan R. and Neudecker, H. "The elimination matrix: some lemmas and applications,"
SIAM Journal on Algebraic Discrete Methods 1, no. 4 (1980): 422-449.
http://www.janmagnus.nl/papers/JRM008.pdf Magnus, Jan R. and Neudecker, H. "Symmetry, 0-1 Matrices and Jacobians,"
Econometric Theory 2 (1986): 157-190.
http://www.janmagnus.nl/papers/JRM014.pdf, Fackler, Paul L. "Notes on Matrix Calculus." (2005).
http://www4.ncsu.edu/~pfackler/MatCalc.pdf MM: DO use @importFrom (whimps use full imports ..) !