Learn R Programming

madness (version 0.2.2)

setter: Setter methods.

Description

Modify slot data of a madness object. Note that the value and the derivative cannot easily be changed, as allowing this form of access would likely result in badly computed derivatives.

Usage

xtag(x) <- value

# S4 method for madness xtag(x) <- value

vtag(x) <- value

# S4 method for madness vtag(x) <- value

varx(x) <- value

# S4 method for madness varx(x) <- value

Arguments

x
a madness object.
value
the new value of the tag or derivative.