A data.frame object with 4800 observations and 5 columns.
The data run from July, 1926 through June, 2018.
As in the upstream source, the data are given in percents, meaning a
value of 1.00 corresponds to a 1% movement.
Note also that returns presumably are ‘simple’ returns, not log
returns, though this is not clarified by the upstream source.
The columns are defined as follows:
DateThe closing data, as a Date object. These are typically Saturdays.
MktThe Market weekly return. Note that the risk free rate has been added back
to the excess returns published by the upstream source.
SMBThe cap factor weekly return.
HMLThe growth factor weekly return.
RFThe risk-free rate, presumably as an weekly rate, though note that no corrections have been
made for weekend effects when adding the risk-free rate back to the market
rate.