powered by
Convert model to a madness object.
as.madness(x, vtag=NULL, xtag=NULL)# S3 method for default as.madness(x, vtag = NULL, xtag = NULL)
# S3 method for default as.madness(x, vtag = NULL, xtag = NULL)
an object which can be fed to coef, and possibly vcov
coef
vcov
an optional name for the \(val\) variable.
an optional name for the \(X\) variable.
A madness object.
Attempts to stuff the coefficients and variance-covariance matrix of a model into a madness object.
# NOT RUN { xy <- data.frame(x=rnorm(100),y=runif(100),z=runif(100)) amod <- lm(z ~ x + y,xy) amad <- as.madness(amod) # }
Run the code above in your browser using DataLab