Learn R Programming

madness (version 0.2.9)

det: Matrix Determinant

Description

Compute the determinant of a matrix. As for base::determinant, a list of the modulus and sign are returned.

Usage

# S3 method for madness
determinant(x, logarithm = TRUE, ...)

det(x, ...)

# S4 method for madness,ANY determinant(x, logarithm = TRUE, ...)

# S4 method for madness,missing determinant(x, logarithm = TRUE, ...)

# S4 method for madness,logical determinant(x, logarithm = TRUE, ...)

Value

a list with elements modulus and sign, which are madness objects.

Arguments

x

madness object.

logarithm

logical; if TRUE (default) return the logarithm of the modulus of the determinant.

...

optional arguments, currently unused.

Author

Steven E. Pav shabbychef@gmail.com