base::determinant,
a list of the modulus and sign are returned.# S3 method for madness
determinant(x, logarithm = TRUE, ...)det(x, ...)
# S4 method for madness,ANY
determinant(x, logarithm = TRUE, ...)
# S4 method for madness,missing
determinant(x, logarithm = TRUE, ...)
# S4 method for madness,logical
determinant(x, logarithm = TRUE, ...)
madness object.TRUE (default) return the
logarithm of the modulus of the determinant.det allowed an optional method argument.
This argument will be ignored but will not produce an error.modulus and sign,
which are madness objects.