vcov.func
a function which takes an object of class lm,
and computes a variance-covariance matrix. If equal to the string
"normal", we assume multivariate normal returns.
df
the number of degrees of freedom to subtract
from the sample size in the denominator of the covariance
matrix estimate. The default value is the number of elements in
the mean, the so-called Bessel's correction.